..  This file is part of Invenio
    Copyright (C) 2014 CERN.

    Invenio is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Invenio is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Invenio; if not, write to the Free Software Foundation, Inc.,
    59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

Features
========

Navigable collection tree
-------------------------

.. image:: /_static/snap1.gif
   :width: 200 px
   :align: left

* Documents organised in collections
* Regular and virtual collection trees
* Customizable portalboxes for each collection
* At CERN, over 1,000,000 documents in 700 collections

.. raw:: html

  <br clear="all" />

Powerful search engine
----------------------

.. image:: /_static/snap2.gif
   :width: 200 px
   :align: left

* Specially designed indexes to provide fast search speed for repositories of up to 2,000,000 records
* Customizable simple and advanced search interfaces
* Combined metadata, fulltext and citation search in one go
* Results clustering by collection

.. raw:: html

  <br clear="all" />

Flexible metadata
-----------------

.. image:: /_static/snap3.gif
   :width: 200 px
   :align: left

* Standard metadata format (MARC)
* Handling articles, books, theses, photos, videos, museum objects and more
* Customizable display and linking rules

.. raw:: html

  <br clear="all" />

User personalization
--------------------

.. image:: /_static/snap4.gif
   :width: 200 px
   :align: left

* user-defined document baskets
* user-defined automated email notification alerts
* basket-sharing within user groups
* Amazon-like user comments for documents in repository and shared baskets

.. raw:: html

  <br clear="all" />

Multiple output formats
-----------------------

.. image:: /_static/invenio_formats.jpg
   :width: 200 px
   :align: left

.. raw:: html

  <br clear="all" />

